@@ -283,7 +283,6 @@ mod test {
     use lightspeed_core::error::{ErrorDetail, LightSpeedError};
     use lightspeed_core::service::validator::order::{MUST_BE_GREATER_OR_EQUAL, MUST_BE_LESS_OR_EQUAL};
     use lightspeed_core::service::validator::Validator;
-    use maplit::*;
 
     /*
         #[test]
@@ -370,16 +369,16 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                    ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                        value: Some(true),
-                    }},
-                "two".to_owned() =>
-                    ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                        value: Some(true),
-                    }},
-            ],
+            fields: HashMap::from([
+                (
+                    "one".to_owned(),
+                    ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(true) } },
+                ),
+                (
+                    "two".to_owned(),
+                    ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(true) } },
+                ),
+            ]),
         };
 
         let result = validate_content(&schema, &content);
@@ -428,11 +427,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap!["two".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                    value: Some(true),
-                }},
-            ],
+            fields: HashMap::from([(
+                "two".to_owned(),
+                ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(true) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -461,11 +459,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap!["one".to_owned() =>
-                ContentFieldValue::String{value: ContentFieldValueArity::Single {
-                    value: Some("hello world".to_owned()),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::String {
+                    value: ContentFieldValueArity::Single { value: Some("hello world".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -500,12 +499,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                    value: Some(false),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(false) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -533,12 +530,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                    value: Some(false),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(false) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -571,12 +566,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::String{value: ContentFieldValueArity::Single {
-                    value: Some("hello world".to_owned()),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::String {
+                    value: ContentFieldValueArity::Single { value: Some("hello world".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -609,12 +604,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::Number{value: ContentFieldValueArity::Single {
-                    value: Some(99),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Number { value: ContentFieldValueArity::Single { value: Some(99) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -648,12 +641,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::Number{value: ContentFieldValueArity::Single {
-                    value: Some(1099),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Number { value: ContentFieldValueArity::Single { value: Some(1099) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -687,12 +678,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::String{value: ContentFieldValueArity::Single {
-                    value: Some("hello world".to_owned()),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::String {
+                    value: ContentFieldValueArity::Single { value: Some("hello world".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -726,12 +717,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::String{value: ContentFieldValueArity::Single {
-                    value: Some("hello world?!?!?!?!?!".to_owned()),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::String {
+                    value: ContentFieldValueArity::Single { value: Some("hello world?!?!?!?!?!".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -768,16 +759,16 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                    ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                        value: None,
-                    }},
-                "two".to_owned() =>
-                    ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                        value: None,
-                    }},
-            ],
+            fields: HashMap::from([
+                (
+                    "one".to_owned(),
+                    ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: None } },
+                ),
+                (
+                    "two".to_owned(),
+                    ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: None } },
+                ),
+            ]),
         };
 
         let result = validate_content(&schema, &content);
@@ -805,11 +796,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap!["one".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Localizable {
-                    values: HashMap::new(),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Boolean { value: ContentFieldValueArity::Localizable { values: HashMap::new() } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -844,12 +834,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "one".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Single {
-                    value: Some(true),
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Boolean { value: ContentFieldValueArity::Single { value: Some(true) } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -886,14 +874,14 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![ "one".to_owned() =>
-                ContentFieldValue::Boolean{value: ContentFieldValueArity::Localizable {
-                    values: hashmap![
-                        "IT".to_owned() => Some(true),
-                        "EN".to_owned() => None,
-                    ],
-                }},
-            ],
+            fields: HashMap::from([(
+                "one".to_owned(),
+                ContentFieldValue::Boolean {
+                    value: ContentFieldValueArity::Localizable {
+                        values: HashMap::from([("IT".to_owned(), Some(true)), ("EN".to_owned(), None)]),
+                    },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -929,10 +917,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "slug".to_owned() =>
-                ContentFieldValue::Slug{value: ContentFieldValueArity::Single { value: Some("a-valid-slug".to_owned()) }},
-            ],
+            fields: HashMap::from([(
+                "slug".to_owned(),
+                ContentFieldValue::Slug {
+                    value: ContentFieldValueArity::Single { value: Some("a-valid-slug".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -954,9 +944,12 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap!["slug".to_owned()
-                => ContentFieldValue::Slug{value: ContentFieldValueArity::Single { value: Some("a---notvalid-slug!".to_owned()) }} ,
-            ],
+            fields: HashMap::from([(
+                "slug".to_owned(),
+                ContentFieldValue::Slug {
+                    value: ContentFieldValueArity::Single { value: Some("a---notvalid-slug!".to_owned()) },
+                },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
@@ -984,12 +977,10 @@ mod test {
         let content = Content {
             updated_ms: 0,
             created_ms: 0,
-            fields: hashmap![
-                "slug".to_owned() =>
-                ContentFieldValue::Slug{value: ContentFieldValueArity::Localizable {
-                    values: HashMap::new(),
-                }},
-            ],
+            fields: HashMap::from([(
+                "slug".to_owned(),
+                ContentFieldValue::Slug { value: ContentFieldValueArity::Localizable { values: HashMap::new() } },
+            )]),
         };
 
         let result = validate_content(&schema, &content);
